Introduction
==================================

tSFM implements algorithms to efficiently compute tRNA Class Informative Features (CIFs) from aligned and functionally annotated tRNA gene complements and visualize them by way of Function Logos, Information Difference (ID) Logos, and Kullback-‐Leibler Divergence (KLD) Logos as originally described for single site features in :cite:`Freyhult2006` and :cite:`Freyhult2007`. tSFM additionally implements methods to calculate Class-Informative Basepair features, provides new methods to compute the statistical significance of tRNA CIFs, calculating distance metrics between Function logos.

.. bibliography:: references.bib
